/// <reference types="node" />
import { User } from '@prisma/client';
import { IncomingMessage, ServerResponse } from 'http';
import { APIError } from './errors';
export declare type NextHandler = (err?: Error | APIError) => void | Promise<void>;
export interface Request<Params = any, Body = any, Cookies = any> extends IncomingMessage {
    id: string;
    ipAddress: string;
    query: Params;
    cookies: Cookies;
    body: Body;
}
export declare type Send<Type> = (body: Type) => void;
export interface Response<Type = any> extends ServerResponse {
    send: Send<Type>;
    json: Send<Type>;
    status: (statusCode: number) => Response<Type>;
    redirect(url: string): Response<Type>;
    redirect(status: number, url: string): Response<Type>;
}
export interface Context<Params = any, Body = any, Cookies = any, Type = any> {
    req: Request<Params, Body, Cookies>;
    res: Response<Type>;
    request: Request<Params, Body, Cookies>;
    response: Response<Type>;
    user: User | null;
}
export declare type Middleware<Params = any, Body = any, Cookies = any, Type = any> = (context: Context<Params, Body, Cookies, Type>, next: NextHandler) => any | Promise<any>;
export declare type Handler<Params = any, Body = any, Cookies = any, Type = any> = (cookiesontext: Context<Params, Body, Cookies, Type>) => any | Promise<any>;
export declare type APIHandler = {
    (handler: Handler): void;
    use<Params = Record<string, string | any>, Body = Record<string, any>, Cookies = Record<string, string>, Type = any>(...handlers: Middleware<Params, Body, Cookies, Type>[]): APIHandler;
    get<Params = Record<string, string | any>, Body = Record<string, any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    head<Params = Record<string, string | any>, Body = Record<string, any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    options<Params = Record<string, string | any>, Body = Record<string, any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    post<Body = Record<string, any>, Params = Record<string, string | any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    put<Body = Record<string, any>, Params = Record<string, string | any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    patch<Body = Record<string, any>, Params = Record<string, string | any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
    delete<Params = Record<string, string | any>, Body = Record<string, any>, Cookies = Record<string, string>, Type = any>(handler: Handler<Params, Body, Cookies, Type>): APIHandler;
};
export declare const handler: APIHandler;
export default handler;
